summaryrefslogtreecommitdiff
path: root/sys/arch/sparc/dev
diff options
context:
space:
mode:
authorTheo de Raadt <deraadt@cvs.openbsd.org>1995-12-27 22:46:50 +0000
committerTheo de Raadt <deraadt@cvs.openbsd.org>1995-12-27 22:46:50 +0000
commit5a0b3ebc5ec5df199cb0a29ba6bebc5220fa73f7 (patch)
tree992185a794279d1863cee58afbfa0879dcb1265d /sys/arch/sparc/dev
parent4291bbd441dc09af069cd9f94ec31e33d7dfbbcb (diff)
from netbsd:
Change splimp -> splnet in Ethernet, ARCnet, and FDDI drivers.
Diffstat (limited to 'sys/arch/sparc/dev')
-rw-r--r--sys/arch/sparc/dev/if_ie.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/sys/arch/sparc/dev/if_ie.c b/sys/arch/sparc/dev/if_ie.c
index 7122605734f..9646afb053a 100644
--- a/sys/arch/sparc/dev/if_ie.c
+++ b/sys/arch/sparc/dev/if_ie.c
@@ -92,7 +92,7 @@ Mode of operation:
shall have the I (IE_CMD_INTR) bit set in the command. This way,
when an interrupt arrives at ieintr(), it is immediately possible
to tell what precisely caused it. ANY OTHER command-sending
- routines should run at splimp(), and should post an acknowledgement
+ routines should run at splnet(), and should post an acknowledgement
to every interrupt they generate.
*/
@@ -1449,7 +1449,7 @@ ie_setupram(sc)
volatile struct ie_sys_ctl_block *scb;
int s;
- s = splimp();
+ s = splnet();
scp = sc->scp;
(sc->memzero)((char *) scp, sizeof *scp);
@@ -1489,7 +1489,7 @@ void
iereset(sc)
struct ie_softc *sc;
{
- int s = splimp();
+ int s = splnet();
printf("%s: reset\n", sc->sc_dev.dv_xname);
@@ -1557,7 +1557,7 @@ command_and_wait(sc, cmd, pcmd, mask)
/*
* XXX
* I don't think this timeout works on suns.
* we are at splimp() in the loop, and the timeout
* stuff runs at software spl (so it is masked off?).
*/
@@ -1793,7 +1793,7 @@ setup_bufs(sc)
/*
* Run the multicast setup command.
- * Called at splimp().
+ * Called at splnet().
*/
static int
mc_setup(sc, ptr)
@@ -1828,7 +1828,7 @@ mc_setup(sc, ptr)
* includes executing the CONFIGURE, IA-SETUP, and MC-SETUP commands, starting
* the receiver unit, and clearing interrupts.
*
* THIS ROUTINE MUST BE CALLED AT splimp() OR HIGHER.
*/
int
ieinit(sc)
@@ -1930,7 +1930,7 @@ ieioctl(ifp, cmd, data)
struct ifreq *ifr = (struct ifreq *)data;
int s, error = 0;
- s = splimp();
+ s = splnet();
switch(cmd) {
@@ -1557,7 +1557,7 @@ command_and_wait(sc, cmd, pcmd, mask)
* XXX
* I don't think this timeout works on suns.
- * we are at splimp() in the loop, and the timeout
+ * we are at splnet() in the loop, and the timeout
* stuff runs at software spl (so it is masked off?).
*/
@@ -1828,7 +1828,7 @@ mc_setup(sc, ptr)
* the receiver unit, and clearing interrupts.
*
- * THIS ROUTINE MUST BE CALLED AT splimp() OR HIGHER.
+ * THIS ROUTINE MUST BE CALLED AT splnet() OR HIGHER.
*/
int